@@ -421,21 +421,15 @@ void ManageMediaPlayerControlTest::moveCurrentTrack()
     connect(&myListener, &TracksListener::trackHasChanged,
             &myPlayList, &MediaPlayList::trackChanged,
             Qt::QueuedConnection);
-    connect(&myListener, &TracksListener::albumAdded,
-            &myPlayList, &MediaPlayList::albumAdded,
+    connect(&myListener, &TracksListener::tracksListAdded,
+            &myPlayList, &MediaPlayList::tracksListAdded,
             Qt::QueuedConnection);
-    connect(&myPlayList, &MediaPlayList::newTrackByIdInList,
-            &myListener, &TracksListener::trackByIdInList,
+    connect(&myPlayList, &MediaPlayList::newEntryInList,
+            &myListener, &TracksListener::newEntryInList,
             Qt::QueuedConnection);
     connect(&myPlayList, &MediaPlayList::newTrackByNameInList,
             &myListener, &TracksListener::trackByNameInList,
             Qt::QueuedConnection);
-    connect(&myPlayList, &MediaPlayList::newTrackByFileNameInList,
-            &myListener, &TracksListener::trackByFileNameInList,
-            Qt::QueuedConnection);
-    connect(&myPlayList, &MediaPlayList::newArtistInList,
-            &myListener, &TracksListener::newArtistInList,
-            Qt::QueuedConnection);
     connect(&myDatabaseContent, &DatabaseInterface::tracksAdded,
             &myListener, &TracksListener::tracksAdded);
 
@@ -466,10 +460,14 @@ void ManageMediaPlayerControlTest::moveCurrentTrack()
 
     QCOMPARE(myControl.playListModel(), &myPlayList);
 
-    myDatabaseContent.insertTracksList(mNewTracks, mNewCovers, QStringLiteral("autoTest"));
+    myDatabaseContent.insertTracksList(mNewTracks, mNewCovers);
 
-    myPlayList.enqueue({QStringLiteral("track1"), QStringLiteral("artist2"), QStringLiteral("album2"), 1, 1});
-    myPlayList.enqueue({QStringLiteral("track2"), QStringLiteral("artist1"), QStringLiteral("album1"), 2, 2});
+    myPlayList.enqueue(ElisaUtils::EntryData{myDatabaseContent.trackIdFromTitleAlbumTrackDiscNumber(QStringLiteral("track1"), QStringLiteral("artist2"), QStringLiteral("album2"), 1, 1),
+                        QStringLiteral("track1")},
+                       ElisaUtils::Track);
+    myPlayList.enqueue(ElisaUtils::EntryData{myDatabaseContent.trackIdFromTitleAlbumTrackDiscNumber(QStringLiteral("track2"), QStringLiteral("artist1"), QStringLiteral("album1"), 2, 2),
+                        QStringLiteral("track2")},
+                       ElisaUtils::Track);
 
     QCOMPARE(playControlEnabledChangedSpy.count(), 0);
     QCOMPARE(skipBackwardControlEnabledChangedSpy.count(), 0);
@@ -526,21 +524,15 @@ void ManageMediaPlayerControlTest::moveAnotherTrack()
     connect(&myListener, &TracksListener::trackHasChanged,
             &myPlayList, &MediaPlayList::trackChanged,
             Qt::QueuedConnection);
-    connect(&myListener, &TracksListener::albumAdded,
-            &myPlayList, &MediaPlayList::albumAdded,
+    connect(&myListener, &TracksListener::tracksListAdded,
+            &myPlayList, &MediaPlayList::tracksListAdded,
             Qt::QueuedConnection);
-    connect(&myPlayList, &MediaPlayList::newTrackByIdInList,
-            &myListener, &TracksListener::trackByIdInList,
+    connect(&myPlayList, &MediaPlayList::newEntryInList,
+            &myListener, &TracksListener::newEntryInList,
             Qt::QueuedConnection);
     connect(&myPlayList, &MediaPlayList::newTrackByNameInList,
             &myListener, &TracksListener::trackByNameInList,
             Qt::QueuedConnection);
-    connect(&myPlayList, &MediaPlayList::newTrackByFileNameInList,
-            &myListener, &TracksListener::trackByFileNameInList,
-            Qt::QueuedConnection);
-    connect(&myPlayList, &MediaPlayList::newArtistInList,
-            &myListener, &TracksListener::newArtistInList,
-            Qt::QueuedConnection);
     connect(&myDatabaseContent, &DatabaseInterface::tracksAdded,
             &myListener, &TracksListener::tracksAdded);
 
@@ -571,10 +563,14 @@ void ManageMediaPlayerControlTest::moveAnotherTrack()
 
     QCOMPARE(myControl.playListModel(), &myPlayList);
 
-    myDatabaseContent.insertTracksList(mNewTracks, mNewCovers, QStringLiteral("autoTest"));
+    myDatabaseContent.insertTracksList(mNewTracks, mNewCovers);
 
-    myPlayList.enqueue({QStringLiteral("track1"), QStringLiteral("artist2"), QStringLiteral("album2"), 1, 1});
-    myPlayList.enqueue({QStringLiteral("track2"), QStringLiteral("artist1"), QStringLiteral("album1"), 2, 2});
+    myPlayList.enqueue(ElisaUtils::EntryData{myDatabaseContent.trackIdFromTitleAlbumTrackDiscNumber(QStringLiteral("track1"), QStringLiteral("artist2"), QStringLiteral("album2"), 1, 1),
+                        QStringLiteral("track1")},
+                       ElisaUtils::Track);
+    myPlayList.enqueue(ElisaUtils::EntryData{myDatabaseContent.trackIdFromTitleAlbumTrackDiscNumber(QStringLiteral("track2"), QStringLiteral("artist1"), QStringLiteral("album1"), 2, 2),
+                        QStringLiteral("track2")},
+                       ElisaUtils::Track);
 
     QCOMPARE(playControlEnabledChangedSpy.count(), 0);
     QCOMPARE(skipBackwardControlEnabledChangedSpy.count(), 0);
@@ -631,21 +627,15 @@ void ManageMediaPlayerControlTest::setCurrentTrackTest()
     connect(&myListener, &TracksListener::trackHasChanged,
             &myPlayList, &MediaPlayList::trackChanged,
             Qt::QueuedConnection);
-    connect(&myListener, &TracksListener::albumAdded,
-            &myPlayList, &MediaPlayList::albumAdded,
+    connect(&myListener, &TracksListener::tracksListAdded,
+            &myPlayList, &MediaPlayList::tracksListAdded,
             Qt::QueuedConnection);
-    connect(&myPlayList, &MediaPlayList::newTrackByIdInList,
-            &myListener, &TracksListener::trackByIdInList,
+    connect(&myPlayList, &MediaPlayList::newEntryInList,
+            &myListener, &TracksListener::newEntryInList,
             Qt::QueuedConnection);
     connect(&myPlayList, &MediaPlayList::newTrackByNameInList,
             &myListener, &TracksListener::trackByNameInList,
             Qt::QueuedConnection);
-    connect(&myPlayList, &MediaPlayList::newTrackByFileNameInList,
-            &myListener, &TracksListener::trackByFileNameInList,
-            Qt::QueuedConnection);
-    connect(&myPlayList, &MediaPlayList::newArtistInList,
-            &myListener, &TracksListener::newArtistInList,
-            Qt::QueuedConnection);
     connect(&myDatabaseContent, &DatabaseInterface::tracksAdded,
             &myListener, &TracksListener::tracksAdded);
 
@@ -676,10 +666,14 @@ void ManageMediaPlayerControlTest::setCurrentTrackTest()
 
     QCOMPARE(myControl.playListModel(), &myPlayList);
 
-    myDatabaseContent.insertTracksList(mNewTracks, mNewCovers, QStringLiteral("autoTest"));
+    myDatabaseContent.insertTracksList(mNewTracks, mNewCovers);
 
-    myPlayList.enqueue({QStringLiteral("track1"), QStringLiteral("artist2"), QStringLiteral("album2"), 1, 1});
-    myPlayList.enqueue({QStringLiteral("track2"), QStringLiteral("artist1"), QStringLiteral("album1"), 2, 2});
+    myPlayList.enqueue(ElisaUtils::EntryData{myDatabaseContent.trackIdFromTitleAlbumTrackDiscNumber(QStringLiteral("track1"), QStringLiteral("artist2"), QStringLiteral("album2"), 1, 1),
+                        QStringLiteral("track1")},
+                       ElisaUtils::Track);
+    myPlayList.enqueue(ElisaUtils::EntryData{myDatabaseContent.trackIdFromTitleAlbumTrackDiscNumber(QStringLiteral("track2"), QStringLiteral("artist1"), QStringLiteral("album1"), 2, 2),
+                        QStringLiteral("track2")},
+                       ElisaUtils::Track);
 
     QCOMPARE(playControlEnabledChangedSpy.count(), 0);
     QCOMPARE(skipBackwardControlEnabledChangedSpy.count(), 0);
