@@ -26,6 +26,8 @@
 #include <QUrl>
 #include <QMediaPlayer>
 
+class QDateTime;
+
 class ELISALIB_EXPORT ManageAudioPlayer : public QObject
 {
     Q_OBJECT
@@ -74,7 +76,7 @@ class ELISALIB_EXPORT ManageAudioPlayer : public QObject
                WRITE setPlayerStatus
                NOTIFY playerStatusChanged)
 
-    Q_PROPERTY(int playerPlaybackState
+    Q_PROPERTY(QMediaPlayer::State playerPlaybackState
                READ playerPlaybackState
                WRITE setPlayerPlaybackState
                NOTIFY playerPlaybackStateChanged)
@@ -111,14 +113,6 @@ class ELISALIB_EXPORT ManageAudioPlayer : public QObject
 
 public:
 
-    enum PlayerPlaybackState {
-        PlayingState = 1,
-        PausedState = 2,
-        StoppedState = 0,
-    };
-
-    Q_ENUM(PlayerPlaybackState)
-
     explicit ManageAudioPlayer(QObject *parent = nullptr);
 
     QPersistentModelIndex currentTrack() const;
@@ -133,7 +127,7 @@ public:
 
     QMediaPlayer::MediaStatus playerStatus() const;
 
-    int playerPlaybackState() const;
+    QMediaPlayer::State playerPlaybackState() const;
 
     QMediaPlayer::Error playerError() const;
 
@@ -193,6 +187,10 @@ Q_SIGNALS:
 
     void seek(qint64 position);
 
+    void saveUndoPositionInAudioWrapper(qint64 position);
+
+    void restoreUndoPositionInAudioWrapper();
+
     void titleRoleChanged();
 
     void artistNameRoleChanged();
@@ -203,10 +201,16 @@ Q_SIGNALS:
 
     void displayTrackError(const QString &fileName);
 
+    void startedPlayingTrack(const QUrl &fileName, const QDateTime &time);
+
 public Q_SLOTS:
 
     void setCurrentTrack(const QPersistentModelIndex &currentTrack);
 
+    void saveForUndoClearPlaylist();
+
+    void restoreForUndoClearPlaylist();
+
     void setPlayListModel(QAbstractItemModel* aPlayListModel);
 
     void setUrlRole(int value);
@@ -215,7 +219,7 @@ public Q_SLOTS:
 
     void setPlayerStatus(QMediaPlayer::MediaStatus playerStatus);
 
-    void setPlayerPlaybackState(int playerPlaybackState);
+    void setPlayerPlaybackState(QMediaPlayer::State playerPlaybackState);
 
     void setPlayerError(QMediaPlayer::Error playerError);
 
@@ -283,7 +287,7 @@ private:
 
     QMediaPlayer::MediaStatus mPlayerStatus = QMediaPlayer::NoMedia;
 
-    PlayerPlaybackState mPlayerPlaybackState = StoppedState;
+    QMediaPlayer::State mPlayerPlaybackState = QMediaPlayer::StoppedState;
 
     QMediaPlayer::Error mPlayerError = QMediaPlayer::NoError;
 
@@ -299,6 +303,10 @@ private:
 
     QVariantMap mPersistentState;
 
+    bool mUndoPlayingState = false;
+
+    qint64 mUndoPlayerPosition = 0;
+
 };
 
 #endif // MANAGEAUDIOPLAYER_H
