@@ -21,24 +21,18 @@
 #include "elisaLib_export.h"
 
 #include "notificationitem.h"
+#include "databaseinterface.h"
 
 #include <QObject>
-
 #include <QMediaPlayer>
 
-#include "musicalbum.h"
-#include "musicartist.h"
-#include "musicaudiotrack.h"
-
 #include <memory>
 
 class MusicListenersManagerPrivate;
-class DatabaseInterface;
 class MediaPlayList;
 class NotificationItem;
 class ElisaApplication;
-class QAbstractItemModel;
-class AbstractMediaProxyModel;
+class ModelDataLoader;
 
 class ELISALIB_EXPORT MusicListenersManager : public QObject
 {
@@ -53,47 +47,35 @@ class ELISALIB_EXPORT MusicListenersManager : public QObject
                READ importedTracksCount
                NOTIFY importedTracksCountChanged)
 
-    Q_PROPERTY(bool indexingRunning
-               READ isIndexingRunning
-               NOTIFY indexingRunningChanged)
-
     Q_PROPERTY(ElisaApplication* elisaApplication
                READ elisaApplication
                WRITE setElisaApplication
                NOTIFY elisaApplicationChanged)
 
-    Q_PROPERTY(QAbstractItemModel* allAlbumsModel
-               READ allAlbumsModel
-               CONSTANT)
-
-    Q_PROPERTY(QAbstractItemModel* allArtistsModel
-               READ allArtistsModel
-               CONSTANT)
-
-    Q_PROPERTY(QAbstractItemModel* allTracksModel
-               READ allTracksModel
-               CONSTANT)
-
-    Q_PROPERTY(QAbstractItemModel* allGenresModel
-               READ allGenresModel
-               CONSTANT)
-
-    Q_PROPERTY(QAbstractItemModel* allLyricistsModel
-               READ allLyricistsModel
-               CONSTANT)
-
-    Q_PROPERTY(QAbstractItemModel* allComposersModel
-               READ allComposersModel
-               CONSTANT)
-
-    Q_PROPERTY(QAbstractItemModel* albumModel
-               READ albumModel
-               CONSTANT)
-
     Q_PROPERTY(bool indexerBusy
                READ indexerBusy
                NOTIFY indexerBusyChanged)
 
+    Q_PROPERTY(bool fileSystemIndexerActive
+               READ fileSystemIndexerActive
+               NOTIFY fileSystemIndexerActiveChanged)
+
+    Q_PROPERTY(bool balooIndexerActive
+               READ balooIndexerActive
+               NOTIFY balooIndexerActiveChanged)
+
+    Q_PROPERTY(bool balooIndexerAvailable
+               READ balooIndexerAvailable
+               NOTIFY balooIndexerAvailableChanged)
+
+    Q_PROPERTY(bool androidIndexerActive
+               READ androidIndexerActive
+               NOTIFY androidIndexerActiveChanged)
+
+    Q_PROPERTY(bool androidIndexerAvailable
+               READ androidIndexerAvailable
+               NOTIFY androidIndexerAvailableChanged)
+
 public:
 
     explicit MusicListenersManager(QObject *parent = nullptr);
@@ -106,26 +88,20 @@ public:
 
     int importedTracksCount() const;
 
-    bool isIndexingRunning() const;
-
     ElisaApplication* elisaApplication() const;
 
-    QAbstractItemModel *allAlbumsModel() const;
-
-    QAbstractItemModel *allArtistsModel() const;
-
-    QAbstractItemModel *allTracksModel() const;
-
-    QAbstractItemModel *allGenresModel() const;
-
-    QAbstractItemModel *allLyricistsModel() const;
-
-    QAbstractItemModel *allComposersModel() const;
-
-    QAbstractItemModel *albumModel() const;
-
     bool indexerBusy() const;
 
+    bool fileSystemIndexerActive() const;
+
+    bool balooIndexerActive() const;
+
+    bool balooIndexerAvailable() const;
+
+    bool androidIndexerActive() const;
+
+    bool androidIndexerAvailable() const;
+
 Q_SIGNALS:
 
     void viewDatabaseChanged();
@@ -134,8 +110,6 @@ Q_SIGNALS:
 
     void importedTracksCountChanged();
 
-    void indexingRunningChanged();
-
     void newNotification(NotificationItem notification);
 
     void closeNotification(QString notificationId);
@@ -148,6 +122,18 @@ Q_SIGNALS:
 
     void indexerBusyChanged();
 
+    void clearDatabase();
+
+    void fileSystemIndexerActiveChanged();
+
+    void balooIndexerActiveChanged();
+
+    void balooIndexerAvailableChanged();
+
+    void androidIndexerActiveChanged();
+
+    void androidIndexerAvailableChanged();
+
 public Q_SLOTS:
 
     void databaseReady();
@@ -158,13 +144,17 @@ public Q_SLOTS:
 
     void setElisaApplication(ElisaApplication* elisaApplication);
 
-    void playBackError(QUrl sourceInError, QMediaPlayer::Error playerError);
+    void playBackError(const QUrl &sourceInError, QMediaPlayer::Error playerError);
+
+    void connectModel(ModelDataLoader *dataLoader);
+
+    void resetMusicData();
 
 private Q_SLOTS:
 
     void configChanged();
 
-    void increaseImportedTracksCount(const QList<MusicAudioTrack> &allTracks);
+    void increaseImportedTracksCount(const DatabaseInterface::ListTrackDataType &allTracks);
 
     void decreaseImportedTracksCount();
 
@@ -172,10 +162,22 @@ private Q_SLOTS:
 
     void monitorEndingListeners();
 
+    void cleanedDatabase();
+
+    void balooAvailabilityChanged();
+
 private:
 
+    void testBalooIndexerAvailability();
+
+    void startLocalFileSystemIndexing();
+
+    void startBalooIndexing();
+
     std::unique_ptr<MusicListenersManagerPrivate> d;
 
+    void createTracksListener();
+
 };
 
 #endif // MUSICLISTENERSMANAGER_H
